==> aliyun-python-sdk-dms-enterprise-1.13.0.tar.gz: aliyun-python-sdk-dms-enterprise-1.13.0/aliyunsdkdms_enterprise/request/v20181101/CreateStructSyncOrderRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdms_enterprise.endpoint import endpoint_data

class CreateStructSyncOrderRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dms-enterprise', '2018-11-01', 'CreateStructSyncOrder','dmsenterprise')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_Tid(self):
		return self.get_query_params().get('Tid')

	def set_Tid(self,Tid):
		self.add_query_param('Tid',Tid)

	def get_AttachmentKey(self):
		return self.get_query_params().get('AttachmentKey')

	def set_AttachmentKey(self,AttachmentKey):
		self.add_query_param('AttachmentKey',AttachmentKey)

	def get_Param(self):
		return self.get_query_params().get('Param')

	def set_Param(self,Param):
		self.add_query_param('Param',Param)

	def get_Comment(self):
		return self.get_query_params().get('Comment')

	def set_Comment(self,Comment):
		self.add_query_param('Comment',Comment)

	def get_RelatedUserList(self):
		return self.get_query_params().get('RelatedUserList')

	def set_RelatedUserList(self,RelatedUserList):
		self.add_query_param('RelatedUserList',RelatedUserList)

==> aliyun-python-sdk-dms-enterprise-1.16.0.tar.gz: aliyun-python-sdk-dms-enterprise-1.16.0/aliyunsdkdms_enterprise/request/v20181101/CreateStructSyncOrderRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdms_enterprise.endpoint import endpoint_data
import json

class CreateStructSyncOrderRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dms-enterprise', '2018-11-01', 'CreateStructSyncOrder')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_Tid(self): # Long
		return self.get_query_params().get('Tid')

	def set_Tid(self, Tid):  # Long
		self.add_query_param('Tid', Tid)
	def get_AttachmentKey(self): # String
		return self.get_query_params().get('AttachmentKey')

	def set_AttachmentKey(self, AttachmentKey):  # String
		self.add_query_param('AttachmentKey', AttachmentKey)
	def get_Param(self): # Struct
		return self.get_query_params().get('Param')

	def set_Param(self, Param):  # Struct
		self.add_query_param("Param", json.dumps(Param))
	def get_Comment(self): # String
		return self.get_query_params().get('Comment')

	def set_Comment(self, Comment):  # String
		self.add_query_param('Comment', Comment)
	def get_RelatedUserList(self): # Array
		return self.get_query_params().get('RelatedUserList')

	def set_RelatedUserList(self, RelatedUserList):  # Array
		self.add_query_param("RelatedUserList", json.dumps(RelatedUserList))
